@@ -1,8 +1,6 @@
-scopus2df<-function(D){
-
+scopus2df <- function(D) {
   # this is a legacy function (for old scripts)
-  DATA=bib2df(D,dbsource="scopus")
-  
+  DATA <- bib2df(D, dbsource = "scopus")
+
   return(DATA)
-  
 }
