@@ -1,6 +1,6 @@
 # utils::globalVariables("where")
 # utils::globalVariables("any_of")
-# utils::globalVariables("if_all")
+utils::globalVariables(c("matches", "KW_Merged"))
 
 #' @import stats
 #' @import dimensionsR
@@ -85,6 +85,7 @@
 #' @importFrom tidyr unite
 #' @importFrom tidyr starts_with
 #' @importFrom tidyr unnest
+#' @importFrom tidyr unite
 #' @importFrom graphics abline
 #' @importFrom grDevices adjustcolor
 #' @importFrom grDevices dev.off
@@ -253,7 +254,6 @@
 #' @importFrom Matrix tril
 #' @importFrom Matrix triu
 #' @importFrom Matrix uniqTsparse
-# @importFrom Matrix unname
 #' @importFrom Matrix unpack
 #' @importFrom Matrix update
 #' @importFrom Matrix updown
@@ -262,6 +262,8 @@
 #' @importFrom stringr str_locate_all
 #' @importFrom stringr str_extract_all
 #' @importFrom stringr str_replace_all
+#' @importFrom stringr str_trim
+#' @importFrom stringr str_split 
 #' @importFrom graphics barplot
 #' @importFrom graphics legend
 #' @importFrom graphics lines
@@ -586,6 +588,50 @@ firstup <- function(x) {
   x
 }
 
+#' Merge DE and ID Fields into a Unified Keywords Column
+#'
+#' This function creates a new column `KW_Merged` by combining the contents of the `DE` (author keywords) and `ID` (keywords plus) fields 
+#' in a bibliographic dataframe. Duplicate keywords within each record are removed, and leading/trailing spaces are trimmed. 
+#' The merged keywords are separated by a semicolon (`;`).
+#'
+#' If the `KW_Merged` column already exists, it will not be overwritten unless `force = TRUE` is specified.
+#'
+#' @param M A dataframe containing at least the `DE` and/or `ID` columns, typically generated by `convert2df()` from the `bibliometrix` package.
+#' @param force Logical. If `TRUE`, an existing `KW_Merged` column will be overwritten. Default is `FALSE`.
+#'
+#' @return A dataframe with an added (or updated) `KW_Merged` column containing deduplicated and cleaned keyword strings.
+#'
+#' @examples
+#' \dontrun{
+#' data(management, package = "bibliometrix")
+#' M <- mergeKeywords(management)
+#' head(M$KW_Merged)
+#' }
+#'
+#' @export
+mergeKeywords <- function(M, force = FALSE){
+  if (force) M <- M %>% select(!matches("KW_Merged")) # force to replace old KW_Merged column 
+  if (!"KW_Merged" %in% names(M)){
+    if (!"DE" %in% names(M)) M$DE <- NA
+    if (!"ID" %in% names(M)) M$ID <- NA
+    M <- M %>% 
+      unite(col = "KW_Merged", DE,ID,sep = "; ", remove = FALSE, na.rm = TRUE) %>% 
+      mutate(KW_Merged = ifelse(KW_Merged=="",NA,KW_Merged)) %>% 
+      mutate(KW_Merged = map_chr(KW_Merged, ~ {
+        .x %>%
+          str_split(";") %>%
+          unlist() %>%
+          str_trim() %>%
+          unique() %>%
+          paste(collapse = "; ")
+      }))
+  }
+  ### bibliometrix>DB class
+  class(M) <- c("bibliometrixDB", "data.frame")
+  return(M)
+}
+
+# adjust node positions in TM
 adjust_positions_oblique <- function(df, xvar = "rcentrality", yvar = "rdensity",
                                      min_dist = 0.5, max_iter = 100, step_factor = 0.5, jitter_strength = 0.1) {
   df_adj <- df
